#
# spec file for package doomsday
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           doomsday
Version:        2.0.3
Release:        lp150.4.5
Summary:        The Doomsday Engine: DOOM/Hertic/Hexen port with pretty graphics
# md2tool is the one being GPL-2.0-only
License:        GPL-2.0+ and GPL-2.0
Group:          Amusements/Games/3D/Shoot
Url:            http://dengine.net/

#Git-Web:	https://github.com/skyjake/Doomsday-Engine
#Git-Clone:	git://github.com/skyjake/Doomsday-Engine
Source:         http://downloads.sf.net/deng/%name-%version.tar.gz
Source2:        %name-rpmlintrc
Patch1:         doomsday-no-abs-icon.patch
Patch2:         doomsday-libs.diff
Patch3:         doomsday-notime.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  Mesa-devel
BuildRequires:  cmake
%if 0%{?suse_version} < 1500
BuildRequires:  gcc6-c++
%else
BuildRequires:  gcc-c++ >= 6
%endif
BuildRequires:  libpng-devel
BuildRequires:  ncurses-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5OpenGLExtensions)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zzip-zlib-config)
# Doomsday uses a modified version of assimp, so no pkgconfig(assimp) here :-(
Provides:       bundled(assimp) = 3.1.1

%if 0%{?suse_version}
Recommends:     timidity timidity-eawpats
%endif
Provides:       jdoom = %version-%release
Provides:       jheretic = %version-%release
Provides:       jhexen = %version-%release
Obsoletes:      deng < %version-%release
Provides:       deng = %version-%release
# Mesa 9.2 has OpenGL 3.1, and doomsday 2.0 needs that.
Requires:       Mesa-libGL1 >= 9.2

%description
The Doomsday Engine is a source port with support for Doom, Heretic,
and Hexen. It does not support BOOM extensions.

%package launcher
Summary:        Graphical launcher for Doomsday
Group:          Amusements/Games/3D/Shoot
Requires:       %name = %version
BuildRequires:  python
%if 0%{?fedora_version}
Requires:       wxPython
%else
%py_requires
Requires:       python-wxWidgets
%endif
%if 0%{?suse_version} >= 1130 || 0%{?fedora_version}
BuildArch:      noarch
%endif

%description launcher
Snowberry is the official frontend of the Doomsday Engine. It is a
portable graphical game launcher, with support for configuring the
various types of games supported by Doomsday. It offers to save your
settings for launching a particular game (e.g., Doom).

%prep
%setup -q
%patch -P 1 -P 2 -P 3 -p1

%build
pushd doomsday
cf="%optflags"
%if 0%{?suse_version} > 1320
cf="$cf -Wno-narrowing"
%endif
%if 0%{?suse_version} < 1500
export CC=gcc-6 CXX=g++-6
%endif
%cmake
make -O %{?_smp_mflags}

%install
b="%buildroot"
pushd doomsday/
%cmake_install
popd
d="$b/%_libdir/doomsday"
rm -Rf "$b/%_includedir" "$b/%_libdir/cmake" "$b/%_datadir/doc/texc" \
	"$d/cmake" "$d/pkgconfig" "$d"/*.a
mkdir -p "$b/%_datadir/pixmaps"
ln -s "%_datadir/%name/deng-shell-logo-256.png" "$b/%_datadir/pixmaps/"
ln -s "%_datadir/%name/deng-logo-256.png" "$b/%_datadir/pixmaps/"

mkdir -p "$b/%_sysconfdir/doomsday";
cat >"$b/%_sysconfdir/doomsday/paths" <<-EOF
	basedir: %_datadir/doomsday
	libdir: %_libdir/doomsday
	iwaddir: %_datadir/doom
EOF

%post
echo "INFO: %name: The global IWAD directory is %_datadir/doom.";
/sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %_sysconfdir/doomsday
%config %_sysconfdir/doomsday/paths
%_bindir/*
%_libdir/libdeng*.so*
%_libdir/%name/
%_datadir/%name/
%_datadir/applications/*.desktop
%_datadir/pixmaps/*.png

%changelog
* Thu Feb  8 2018 jengelh@inai.de
- Get rid of BuildRequires: xorg-x11-devel.
* Sun Jan 14 2018 jengelh@inai.de
- Add bundled() markers
* Thu Dec 14 2017 jengelh@inai.de
- Update to new bugfix release 2.0.3
  * Server had crashed during startup with error messages related
    to threading
  * Non-standard C++ code had led to crash when using gcc7
  * Removed duplicate IWAD spec for Heretic 1.3 /
    Shadow of the Serpent Riders
  * Hexen: fix crash after returning to a different map in a hub
- Add doomsday-libs.diff, doomsday-notime.diff
* Thu Apr 20 2017 jengelh@inai.de
- Update to new upstream release 2.0
  * The Home Screen replaces the front-end app. The Python-based
    Snowberry launcher application was created in 2005 and has been
    used for starting Doomsday ever since. In version 2.0, the
    launcher is no longer needed because Doomsday's Home Screen
    (previously called "ring zero") replaces its functionality.
  * Built-in support for packages. One of the launcher's key features
    was add-on management. This is now also part of Doomsday itself
    in the form of packages. Anything that Doomsday can load — WADs,
    resource packs, 3D models, etc. — is now handled via the same
    package management system. This enables Doomsday to track which
    files are in use in saved games and multiplayer games, and makes
    it possible to automatically ensure that the correct files are
    loaded at any given time.
  * New 3D model renderer. Doomsday's graphics code is undergoing a
    transition to a newer version of OpenGL, namely "OpenGL3/4 Core
    Profile"). Certain parts like the engine UI have already
    completed this transition, however the game renderer itself has
    not. In version 2.0, the new version of the 3D model renderer has
    reached a state where it is useful for actual gameplay. This new
    renderer supports FBX and MD5 models (among other formats),
    skeletal animation, GLSL shaders, and Doomsday Script.
* Sat Jun 18 2016 jengelh@inai.de
- Update to new upstream release 1.15.8
  * Custom episodes. Episode (DED) definitions specify the structure of
  game episodes (including hubs) enabling entirely new episodes and
  modifying the originals.
  * MAPINFO support. MAPINFO (Hexen) definitions are now supported in
  Doom and Heretic, as well as Hexen. Note that, presently, only the
  Hexen dialect of MAPINFO is supported (ZDoom uses its own MAPINFO
  dialect).
  * Adjustable pixel density. If your GPU is on the slower side, you
  can improve performance by reducing game view resolution. The rest
  of the UI remains sharp since the display mode is not changed. As a
  bonus, you can also get a nice nostalgic aesthetic similar to the
  original Doom on a CRT display.
- If you get a blank screen instead of the game title screen
  after selecting the IWAD to play, you may need to reset your
  settings (~/.doomsday)!
- Added doomsday-ncurses.diff (work around absence of ncurses.pc
  in not-too-new ncurses)
* Thu Jun 16 2016 jengelh@inai.de
- Add -Wno-narrowing to let gcc6 build pass
* Mon Mar 30 2015 dimstar@opensuse.org
- Add doomsday-no-abs-icon.patch: Do not use absolute path to
  icons. Applicatio containerisation requires the icons to be below
  /usr/share/icons or /usr/share/pixmaps.
- Copy the icons from the app directory to /usr/share/pixmaps.
* Sun Oct 12 2014 jengelh@inai.de
- Update to new upstream release 1.14.5, which fixes:
  * Hexen: Loading autosaved progress on a previously visited map
  loads an out of date save state
  * Hexen: Number of inventory items increases when going through
  a portal
  * Hexen: Puzzle progress in main hub not showing up
* Tue May 20 2014 jengelh@inai.de
- Update to new upstream release 1.14.3, which fixes:
  * Hexen: Hub maps reset after saving, causing invalid game world
  state
  * Doom 2: Crash playing sci2.wad MAP13
  * Better compatibility with vanilla Doom renderer: dynamic
  map hacks dependent on non-neighbor planes
  * Hexen: Saving error — "already exists"
* Thu May  1 2014 jengelh@inai.de
- Update to new upstream release 1.14.1, which fixes:
  * particles were shut off shortly after level start
  * flickering light decoration on moving platform
  * letterboxed/pillarboxed drawing of the game was broken
  * Heretic ghost mummies' floating spirits were not disappearing
  after death
  * Shift key state was not recognized by bindings when typing in
  console
  * Multiplayer weapons were not remaining in play
  * Gracefully abort if OpenGL version is not sufficient
* Wed Apr 23 2014 jengelh@inai.de
- Update to new upstream release 1.14
  * It adds bloom to Doomsday's visual features. The last of the
  old UI has been replaced, and now MP games and save games, due
  to a new save game format, from all games can be accessed from
  the taskbar or home screen (formerly Ring Zero). New alert and
  tutorial notifications have been added to inform users of any
  important engine, map and resource errors and about the UI.
* Mon Jan  6 2014 jengelh@inai.de
- Update to new upstream release 1.13.1
  * Multiplayer: Resolve crash when joining a multiplayer game using
  the Vanilla appearance profile
  * Multiplayer: Resolve crash when more than one client joins a game
  * Multiplayer: Missing busy mode transition frame when joining
  a game
  * UI: Using keyboard bindings when a popup is open in the UI
  (e.g. pressing F11 to toggle screen when the DE menu is open in
  the task bar)
  * Added the -nodiscovery option to prevent Doomsday from looking
  for running servers on the LAN
* Fri Jan  3 2014 jengelh@inai.de
- Update to new upstream release 1.13
  * Framebuffer effects. Doomsday can now use OpenGL shaders to
  post-process the rendered frames. In this release, this has been
  applied this for libdoom's Invulnerability power-up effect.
  * Stereoscopic 3D. Support has been added for various stereoscopic
  rendering modes, including anaglyph, side-by-side, parallel and
  cross-eyed viewing.
* Mon Nov 11 2013 jengelh@inai.de
- Update to new upstream release 1.12.2
  * console: fix crash when autocompleting certain words (e.g. "upd")
  * task bar: Added toggle for sound-overlap-stop to Audio Settings:
  when enabled, only one sound is allowed per emitter (like in the
  original games)
- Remove deng-va-list.diff (merged upstream)
- OpenGL 2.x is required for Doomsday 1.12
* Sun Oct  6 2013 jengelh@inai.de
- Update to new upstream release 1.12
  * The old Control Panel and Updater have been retired and their
  functionality merged into the taskbar. New taskbar features
  include background downloading of updates, profiles for renderer
  settings, and auto completion of console commands. There is also
  vastly improved map rendering hack support, and 3D sound can now
  separate isolated parts of joined sectors.
* Tue Jul 30 2013 jengelh@inai.de
- Update to new upstream release 1.11.0
  * Doomsday has received a new mouse-driven UI; the taskbar
  replaces the old console.
* Thu May 23 2013 jengelh@inai.de
- Update to new upstream release 1.10.3
  * resolve stuck TEXTUREn lump loading with Hell Revealed II
  * fog should not be applied to weapon psprites
- Remove deng-nodate.diff: kill __DATE__ with shell instead of patch
* Thu Apr 18 2013 jengelh@inai.de
- Supply path configuration file and kill the shell wrappers that
  supplied the paths via command line before.
* Tue Apr  9 2013 jengelh@inai.de
- Update to new upstream release 1.10
  * the multiplayer server is now its own separate executable that
  users control using the new "Shell" application
- Remove deng-libdir.diff (merged upstream)
* Tue Mar 19 2013 schwab@suse.de
- deng-va-list.diff: Remove non-portable use of va_list
* Sun Feb 17 2013 jengelh@inai.de
- Correctly place files into %%_libdir (original sr#147463)
* Sun Jan  6 2013 jengelh@inai.de
- Update to new upstream release 1.9.10.1
  * The longstanding gameplay bug that prevented a column from
  lowering on Doom E1M7 has now been fixed.
  * Command-line tools for creating and editing data files (md2tool,
  texc) are now included as part of the distribution packages.
* Thu Oct  4 2012 jengelh@inai.de
- Update to new upstream release 1.9.9
  * Faster map loading thanks to optimizations in the BSP builder.
  * Improved music support for OS X 10.6+ and Linux: SF2 soundfonts
  can be used with the original games' MIDI music.
* Mon Jul  9 2012 jengelh@inai.de
- Bump importance of timidity from Suggested to Recommended. (Few
  users actually have FMOD (alternative output plugin) installed.)
* Sun Jun 24 2012 jengelh@inai.de
- Initial package (version 1.9.8) for build.opensuse.org
